@@ -9,14 +9,13 @@ from drf_spectacular.utils import OpenApiExample, OpenApiParameter, extend_schem
     extend_schema_view
 from rest_framework import mixins, status, viewsets
 from rest_framework.parsers import FileUploadParser, FormParser, MultiPartParser
-from rest_framework.permissions import IsAuthenticated
 from rest_framework.renderers import BrowsableAPIRenderer, JSONRenderer
 from rest_framework.response import Response
 from rest_framework.serializers import ValidationError
 
 from db.api import filters, pagination, serializers
 from db.api.parsers import JSONLDParser
-from db.api.perms import SafeMethodsWithPermission
+from db.api.perms import IsAuthenticatedOrOptions, SafeMethodsWithPermission
 from db.api.renderers import BrowserableJSONLDRenderer, JSONLDRenderer
 from db.base.helpers import gridsquare
 from db.base.models import SATELLITE_STATUS, SERVICE_TYPE, TRANSMITTER_STATUS, TRANSMITTER_TYPE, \
@@ -279,8 +278,8 @@ class TransmitterViewSet(  # pylint: disable=R0901
     ]
     parser_classes = [JSONLDParser]
     queryset = Transmitter.objects.filter(
-        satellite__associated_satellite__isnull=True, satellite__satellite_entry__approved=True
-    )
+        satellite__satellite_entry__approved=True, satellite__associated_satellite__isnull=True
+    ).exclude(status='invalid')
     serializer_class = serializers.TransmitterSerializer
     filterset_class = filters.TransmitterViewFilter
     lookup_field = 'uuid'
@@ -539,7 +538,10 @@ class TelemetryViewSet(  # pylint: disable=R0901,R0912,R0915
         norad_id = request.data.get('noradID')
 
         try:
-            satellite = Satellite.objects.get(satellite_entry__norad_cat_id=norad_id)
+            if norad_id:
+                satellite = Satellite.objects.get(satellite_entry__norad_cat_id=norad_id)
+            else:
+                raise ValueError
         except Satellite.DoesNotExist:
             satellite_identifier = SatelliteIdentifier.objects.create()
             satellite_entry = SatelliteEntry.objects.create(
@@ -649,7 +651,7 @@ class ArtifactViewSet(  # pylint: disable=R0901
     """
     queryset = Artifact.objects.all()
     filterset_class = filters.ArtifactViewFilter
-    permission_classes = [IsAuthenticated]
+    permission_classes = [IsAuthenticatedOrOptions]
     parser_classes = (FormParser, MultiPartParser)
     pagination_class = pagination.LinkedHeaderPageNumberPagination
 
