@@ -1,10 +1,10 @@
 """SatNOGS DB django base Forms class"""
-from bootstrap_modal_forms.forms import BSModalModelForm
+from bootstrap_modal_forms.forms import BSModalForm, BSModalModelForm
 from django.core.exceptions import ValidationError
-from django.forms import TextInput
+from django.forms import ModelChoiceField, TextInput
 from django.utils.translation import gettext_lazy as _
 
-from db.base.models import SatelliteEntry, Transmitter, TransmitterEntry
+from db.base.models import Satellite, SatelliteEntry, Transmitter, TransmitterEntry
 
 
 def existing_uuid(value):
@@ -103,3 +103,42 @@ class SatelliteUpdateForm(BSModalModelForm):
             'operator': _('Owner/Operator'),
         }
         widgets = {'names': TextInput()}
+
+
+class MergeSatellitesForm(BSModalForm):
+    """Form that uses django-bootstrap-modal-forms for merging satellites"""
+    primary_satellite = ModelChoiceField(
+        label=_('Primary Satellite'),
+        queryset=Satellite.objects.filter(
+            associated_satellite__isnull=True, satellite_entry__approved=True
+        ),
+        empty_label="Select the Primary Satellite"
+    )
+    associated_satellite = ModelChoiceField(
+        label=_('Associated Satellite'),
+        queryset=Satellite.objects.filter(
+            associated_satellite__isnull=True, satellite_entry__approved=True
+        ),
+        empty_label="Select the Associated Satellite"
+    )
+
+    def clean(self):
+        if any(self.errors):
+            # If there are errors in forms validation no need for validating the formset
+            return
+
+        cleaned_data = super().clean()
+        primary_satellite = cleaned_data.get("primary_satellite")
+        associated_satellite = cleaned_data.get("associated_satellite")
+
+        if primary_satellite == associated_satellite:
+            self.add_error(
+                'associated_satellite',
+                ValidationError(
+                    _('Associated Satellite can not be the same with the Primary Satellite'),
+                    code='invalid'
+                )
+            )
+
+    class Meta:
+        fields = ['primary_satellite', 'associated_satellite']
