@@ -33,7 +33,7 @@ BASE_URLPATTERNS = (
         path('users/edit/', views.users_edit, name='users_edit'),
         path('robots.txt', views.robots, name='robots'),
         path('search/', views.search, name='search_results'),
-        path('merge_satellites/', views.merge_satellites, name='merge_satellites'),
+        path('merge_satellites/', views.MergeSatellitesView.as_view(), name='merge_satellites'),
         path('create_satellite/', views.SatelliteCreateView.as_view(), name='create_satellite'),
         path(
             'update_satellite/<int:pk>/',
