@@ -406,18 +406,14 @@ def decode_data(sat_id, demoddata_id=None, redecode=False):
                 data = data.filter(pk=demoddata_id, is_decoded=False)
         else:
             # Get a list of all associated satellites for decoding all related data
-            associated_satellites = list(
-                satellite.associated_with.all().values_list('pk', flat=True)
-            )
-            satellites = associated_satellites.append(satellite.pk)
+            satellites_list = list(satellite.associated_with.all().values_list('pk', flat=True))
+            satellites_list.append(satellite.pk)
             if redecode:
-                data = data.filter(satellite_identifier__sat_id__in=satellites)
+                data = data.filter(satellite__in=satellites_list)
             else:
                 time_period = make_aware(datetime.utcnow() - timedelta(hours=48))
                 data = data.filter(
-                    satellite_identifier__sat_id__in=satellites,
-                    timestamp__gte=time_period,
-                    is_decoded=False
+                    satellite__in=satellites_list, timestamp__gte=time_period, is_decoded=False
                 )
 
         with transaction.atomic():
@@ -465,7 +461,7 @@ def cache_statistics():
                         default=sat['latest_payload']
                     )
             else:
-                sat_id = sat_stats[sat['associated_satellite']]
+                sat_id = sat['associated_satellite']
                 del sat['associated_satellite']
                 sat_stats[sat_id] = sat
         else:
